import { defineComponent, reactive, TransitionGroup, watch } from 'vue'
import styles from './index.module.less'
import OHeader from '@/components/o-header'
import OSearch from '@/components/o-search'
import request from '@/helpers/request'
import { setLogin, state } from '@/state'
import { useRoute, useRouter } from 'vue-router'
import OLoading from '@/components/o-loading'
import OEmpty from '@/components/o-empty'
import { Cell, Collapse, CollapseItem } from 'vant'
import ChildNode, { getImage } from './child-node'
import { usePageVisibility } from '@vant/use'
import iconMenu from './image/icon-menu.png'
import OSticky from '@/components/o-sticky'
import { browser } from "@/helpers/utils";
import {  postMessage } from '@/helpers/native-message';
import { handleCheckVip } from '../hook/useFee'

export default defineComponent({
  name: 'course-list-search',
  setup() {
    const route = useRoute()
    const router = useRouter()
    const pageVisibility = usePageVisibility()
    const browserInfo = browser()
    const data = reactive({
      titleOpacity: 0,
      loading: true,
      list: [] as any,
      search: '' as string | undefined,
      parentCollapse: '' as any
      // childrenCollapse: '' as any
    })
    const formatDataList = (list: any = []) => {
      const tempList: any = []
      list.forEach((item: any) => {
        let tempChild: any = {}
        item.collapse = ''
        tempChild = item
        if (Array.isArray(item.children)) {
          tempChild.children = formatDataList(item.children)
        }
        tempList.push({
          ...tempChild
        })
      })
      return tempList
    }

    const formatSelectFirstChild = (list: any = []): any => {
      for (let i = 0; i < list.length; i++) {
        if (Array.isArray(list[i].materialList) && list[i].materialList.length > 0) {
          const materialItem = list[i].materialList[0] || {}
          if (materialItem) {
            return materialItem
          }
        } else {
          return formatSelectFirstChild(list[i].children || [])
        }
      }
    }

    //
    function selectFirstChild(pointList: any[], ids: any[]): any[] {
      return pointList.map((point) => {
        if (point.children) {
          let id = ''
          point.children.map((item: any) => {
            if (!id) {
              id = ids.includes(item.id) ? item.id : ''
            }
          })
          point.collapse = id
          return Object.assign(point, {
            children: selectFirstChild(point.children, ids)
          })
        } else {
          return Object.assign(point, {
            materialList: point.materialList
          })
        }
      })
    }

    function filterPointList(
      pointList: any[],
      parentData?: { ids: string[]; name: string }
    ): any[] {
      // 设置父级及以上id数组和父级name
      return pointList.map((point) => {
        if (point.children) {
          return Object.assign(point, {
            children: filterPointList(point.children, {
              ids: [...(parentData?.ids || []), point.id],
              name: point.name
            })
          })
        } else {
          return Object.assign(point, {
            materialList: point.materialList.map((item: any) => {
              item.parentData = {
                ids: [...(parentData?.ids || []), point.id],
                name: point.name
              }
              return item
            })
          })
        }
      })
    }

    const getList = async (search?: string) => {
      data.loading = true
        try {
          const res: any = await request.post(
            state.platformApi + '/courseSchedule/myCoursewareDetail/' + route.query.id, {
              requestType: "form",
              data: {
                search,
                searchFlag: true
              }
            }
          )
          if (Array.isArray(res?.data)) {
            const _list = res.data
            data.search = search;
            _list.forEach((item: any) => {
              item.children = item.knowledgePointList || [];
              item.id = item.lessonCoursewareDetailId;
              item.name = item.coursewareDetailName;
              formatDataList(item.children);
            });
            let list = filterPointList(_list)
            const firstItem = formatSelectFirstChild(list)
            list = selectFirstChild(list, firstItem?.parentData?.ids || [])
            list.forEach((item: any) => {
              if (item.id === firstItem.parentData?.ids[0]) {
                data.parentCollapse = item.id
              }
            })
            data.list = list
          }
        } catch (error) {}
      
      data.loading = false
    }
    getList()

    // 获取子节点数据
    const getKnowledgeMaterials = (list: any = []) => {
      const tempList: any = []
      list.forEach((item: any) => {
        if (item.materialList && item.materialList.length > 0) {
          tempList.push(...(item.materialList || []))
        }

        if (item.children && item.children.length > 0) {
          tempList.push(...getKnowledgeMaterials(item.children || []))
        }
      })
      return tempList
    }

    const handleClick = (item: any) => {
      const ids = item.parentData?.ids || null
      if(ids) {
        let parentItem: any = {}
        data.list.forEach((item: any) => {
          if (item.id === ids[0]) {
            parentItem = item
          }
        })
        // 判断是否为VIP
        if(parentItem.id) {
          const hasFree = String(parentItem.accessScope) === '0'
          if (!hasFree) {
            const hasVip = handleCheckVip()
            if (!hasVip) return
          }
        }
      }

      if (browser().isApp) {
        postMessage({
          api: 'openWebView',
          content: {
            url: `${location.origin}${location.pathname}#/coursewarePlay?lessonId=${route.query.id}&source=search&kId=${item.id}&search=${encodeURIComponent(data.search||"")}`,
            orientation: 0,
            isHideTitle: true,
            statusBarTextColor: false,
            isOpenLight: true,
            showLoadingAnim: true
          }
        });
      } else {
        router.push({
          path: '/coursewarePlay',
          query: {
            lessonId: route.query.id,
            kId: item.id,
            search: data.search,
            source: 'search'
          }
        });
      }
    }

    const getUserInfo = async () => {
      try {
        // 重新初始化用户信息
        const userCash = await request.get(state.platformApi + '/user/getUserInfo')
        setLogin(userCash.data)
      } catch {
        //
      }
    }

    /** 页面显示和隐藏 */
    watch(
      () => pageVisibility.value,
      (value) => {
        if (value === "visible") {
          getUserInfo()
        }
      }
    )

    return () => (
      <div class={styles.courseListSearch}>
        <OSticky position="top">
          <OHeader background={`rgba(255,255,255, ${data.titleOpacity})`} border={false}>
            {{
              title: () => (
                <div class={styles.title}>
                  <OSearch
                    inputBackground="white"
                    background="transparent"
                    placeholder="请输入素材关键词"
                    onSearch={(val: string) => {
                      getList(val)
                    }}
                  />
                </div>
              )
            }}
          </OHeader>
        </OSticky>

        <div style="height: calc(100vh - var(--header-height)); overflow-x: hidden; overflow-y: auto;">
          <TransitionGroup name="van-fade">
            {!data.loading && (
              <Collapse
                key="courseListSearch"
                modelValue={data.parentCollapse}
                onUpdate:modelValue={(val: any) => {
                  data.parentCollapse = val
                  // data.childrenCollapse = ''; // 重置子项选择
                }}
                class={styles.collapseParent}
                border={false}
                accordion
              >
                {data.list.map((item: any) => (
                  <CollapseItem
                    center
                    border={true}
                    name={item.lessonCoursewareDetailId}
                    clickable={false}
                    class={['parentCollapse__item']}
                  >
                    {{
                      title: () => (
                        <div class={[styles.itemTitle]}>
                          <img src={iconMenu} class={styles.iconMenu} />
                          {item.coursewareDetailName}
                        </div>
                      ),
                      default: () => (
                        <>
                          {Array.isArray(item?.materialList) &&
                            item.materialList.map((n: any) => (
                              <Cell center isLink clickable={false}>
                                {{
                                  title: () => (
                                    <div class={styles.materialSection}>
                                      <img src={getImage(n)} class={styles.iconMaterial} />
                                      {n.name}
                                    </div>
                                  )
                                }}
                              </Cell>
                            ))}
                          {Array.isArray(item?.children) && (
                            <ChildNode
                              id={route.query.id as any}
                              search={data.search}
                              list={item.children}
                              collapse={item.collapse}
                              onUpdate:collapse={(val: any) => {
                                item.collapse = val
                              }}
                              onHandleClick={(item: any) => {
                                handleClick(item)
                              }}
                            />
                          )}
                        </>
                      ),
                      'right-icon': () => (
                        <i
                          class={[
                            styles.arrow,
                            data.parentCollapse === item.lessonCoursewareDetailId
                              ? styles.arrowActive
                              : ''
                          ]}
                        ></i>
                      )
                    }}
                  </CollapseItem>
                ))}
              </Collapse>
            )}
          </TransitionGroup>
          {data.loading && <OLoading />}
          {!data.loading && !data.list.length && <OEmpty tips="暂无搜索结果" />}
        </div>
      </div>
    )
  }
})
